Package: languageserversetup
Type: Package
Title: Automated Setup and Auto Run for R Language Server
Version: 0.1.2
Authors@R: person("Jozef", "Hajnala", email = "jozef.hajnala@gmail.com", role = c("aut", "cre"))
Maintainer: Jozef Hajnala <jozef.hajnala@gmail.com>
Description: Allows to install the R 'languageserver' with all dependencies
    into a separate library and use that independent installation
    automatically when R is instantiated as a language server process.
    Useful for making language server seamless to use without
    running into package version conflicts.
License: AGPL-3
Suggests: tinytest
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.0.1
SystemRequirements: procps (linux), ps (macos), wmic (windows)
URL: https://github.com/jozefhajnala/languageserversetup
BugReports: https://github.com/jozefhajnala/languageserversetup/issues
Language: en-US
NeedsCompilation: no
Packaged: 2020-04-10 08:46:08 UTC; root
Author: Jozef Hajnala [aut, cre]
Repository: CRAN
Date/Publication: 2020-04-10 09:20:02 UTC
Built: R 4.6.0; ; 2026-04-26 20:58:18 UTC; unix
