# Generated by roxygen2: do not edit by hand

S3method(get_docall_args,darwin)
S3method(get_docall_args,default)
S3method(get_docall_args,windows)
export(languageserver_add_to_rprofile)
export(languageserver_install)
export(languageserver_remove_from_rprofile)
export(languageserver_startup)
importFrom(utils,install.packages)
importFrom(utils,installed.packages)
